@@ -141,7 +141,7 @@ sub get_wc_prop {
 
 package SVN::Pusher ;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 use SVN::Core;
 use SVN::Repos;
 use SVN::Fs;
@@ -444,7 +444,7 @@ L<http://svn.berlios.de/svnroot/repos/web-cpan/SVN-Pusher/>
 
 =head1 AUTHORS
 
-Shlomi Fish E<lt>shlomif@iglu.org.ilE<gt>
+Shlomi Fish ( L<http://www.shlomifish.org/> ).
 
 (based on SVN::Push by Gerald Richter E<lt>richter@dev.ecos.deE<gt>)
 
